==> ctxR_1.0.0.tar.gz: ctxR/tests/testthat/chemical/chemical/search/equal/gvfds.R <==
structure(list(url = "https://api-ccte.epa.gov/chemical/search/equal/gvfds", 
    status_code = 400L, headers = structure(list(`content-type` = "application/problem+json", 
        `transfer-encoding` = "chunked", connection = "keep-alive", 
        date = "Tue, 21 May 2024 17:13:54 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
        `strict-transport-security` = "max-age=31536000", `x-content-type-options` = "nosniff", 
        `x-vcap-request-id` = "382cd52a-3f24-4499-6452-3996c1cc2de3", 
        `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
        `x-cache` = "Error from cloudfront", via = "1.1 d7b509440ac55e6d7b3c4c7ad48b08f2.cloudfront.net (CloudFront)", 
        `x-amz-cf-pop` = "IAH50-C2", `x-amz-cf-id` = "i5RM0_Kgr0qq4d_JIydXknzxAp0_T61X_NYPjvKndc5Ow_z8hhbwxA=="), class = c("insensitive", 
    "list")), all_headers = list(list(status = 400L, version = "HTTP/1.1", 
        headers = structure(list(`content-type` = "application/problem+json", 
            `transfer-encoding` = "chunked", connection = "keep-alive", 
            date = "Tue, 21 May 2024 17:13:54 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
            `strict-transport-security` = "max-age=31536000", 
            `x-content-type-options` = "nosniff", `x-vcap-request-id` = "382cd52a-3f24-4499-6452-3996c1cc2de3", 
            `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
            `x-cache` = "Error from cloudfront", via = "1.1 d7b509440ac55e6d7b3c4c7ad48b08f2.cloudfront.net (CloudFront)", 
            `x-amz-cf-pop` = "IAH50-C2", `x-amz-cf-id` = "i5RM0_Kgr0qq4d_JIydXknzxAp0_T61X_NYPjvKndc5Ow_z8hhbwxA=="), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = as.raw(c(0x7b, 0x0a, 0x20, 0x20, 0x22, 0x74, 0x79, 
    0x70, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x61, 0x62, 0x6f, 
    0x75, 0x74, 0x3a, 0x62, 0x6c, 0x61, 0x6e, 0x6b, 0x22, 0x2c, 
    0x0a, 0x20, 0x20, 0x22, 0x74, 0x69, 0x74, 0x6c, 0x65, 0x22, 
    0x20, 0x3a, 0x20, 0x22, 0x42, 0x61, 0x64, 0x20, 0x52, 0x65, 
    0x71, 0x75, 0x65, 0x73, 0x74, 0x22, 0x2c, 0x0a, 0x20, 0x20, 
    0x22, 0x73, 0x74, 0x61, 0x74, 0x75, 0x73, 0x22, 0x20, 0x3a, 
    0x20, 0x34, 0x30, 0x30, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x64, 
    0x65, 0x74, 0x61, 0x69, 0x6c, 0x22, 0x20, 0x3a, 0x20, 0x22, 
    0x53, 0x65, 0x61, 0x72, 0x63, 0x68, 0x65, 0x64, 0x20, 0x62, 
    0x79, 0x20, 0x53, 0x79, 0x6e, 0x6f, 0x6e, 0x79, 0x6d, 0x3a, 
    0x20, 0x46, 0x6f, 0x75, 0x6e, 0x64, 0x20, 0x30, 0x20, 0x72, 
    0x65, 0x73, 0x75, 0x6c, 0x74, 0x73, 0x20, 0x66, 0x6f, 0x72, 
    0x20, 0x27, 0x67, 0x76, 0x66, 0x64, 0x73, 0x27, 0x2e, 0x22, 
    0x2c, 0x0a, 0x20, 0x20, 0x22, 0x69, 0x6e, 0x73, 0x74, 0x61, 
    0x6e, 0x63, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x2f, 0x63, 
    0x68, 0x65, 0x6d, 0x69, 0x63, 0x61, 0x6c, 0x2f, 0x73, 0x65, 
    0x61, 0x72, 0x63, 0x68, 0x2f, 0x65, 0x71, 0x75, 0x61, 0x6c, 
    0x2f, 0x67, 0x76, 0x66, 0x64, 0x73, 0x22, 0x2c, 0x0a, 0x20, 
    0x20, 0x22, 0x73, 0x75, 0x67, 0x67, 0x65, 0x73, 0x74, 0x69, 
    0x6f, 0x6e, 0x73, 0x22, 0x20, 0x3a, 0x20, 0x5b, 0x20, 0x22, 
    0x61, 0x70, 0x66, 0x64, 0x73, 0x22, 0x2c, 0x20, 0x22, 0x75, 
    0x70, 0x66, 0x64, 0x73, 0x22, 0x2c, 0x20, 0x22, 0x70, 0x66, 
    0x64, 0x73, 0x22, 0x2c, 0x20, 0x22, 0x76, 0x66, 0x64, 0x66, 
    0x22, 0x20, 0x5d, 0x0a, 0x7d)), date = structure(1716311634, class = c("POSIXct", 
    "POSIXt"), tzone = "GMT"), times = c(redirect = 0, namelookup = 7.2e-05, 
    connect = 0, pretransfer = 0.000235, starttransfer = 0.278784, 
    total = 0.278825)), class = "response")

==> ctxR_1.1.0.tar.gz: ctxR/tests/testthat/chemical/chemical/search/equal/gvfds.R <==
structure(list(url = "https://api-ccte.epa.gov/chemical/search/equal/gvfds", 
    status_code = 400L, headers = structure(list(`content-type` = "application/problem+json", 
        `transfer-encoding` = "chunked", connection = "keep-alive", 
        date = "Fri, 08 Nov 2024 15:46:58 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
        `strict-transport-security` = "max-age=31536000", `x-content-type-options` = "nosniff", 
        `x-vcap-request-id` = "c7fdad03-a58a-4414-50c6-e3967c60e762", 
        `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
        `x-cache` = "Error from cloudfront", via = "1.1 58f689028f521999dd25fa234ad8a3f4.cloudfront.net (CloudFront)", 
        `x-amz-cf-pop` = "IAD55-P7", `x-amz-cf-id` = "ooh58Lbl9IEROJ-KYJqimQLI0vxWpVuP9t91QsVX8JrfYZ7RuPK56g=="), class = c("insensitive", 
    "list")), all_headers = list(list(status = 400L, version = "HTTP/1.1", 
        headers = structure(list(`content-type` = "application/problem+json", 
            `transfer-encoding` = "chunked", connection = "keep-alive", 
            date = "Fri, 08 Nov 2024 15:46:58 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
            `strict-transport-security` = "max-age=31536000", 
            `x-content-type-options` = "nosniff", `x-vcap-request-id` = "c7fdad03-a58a-4414-50c6-e3967c60e762", 
            `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
            `x-cache` = "Error from cloudfront", via = "1.1 58f689028f521999dd25fa234ad8a3f4.cloudfront.net (CloudFront)", 
            `x-amz-cf-pop` = "IAD55-P7", `x-amz-cf-id` = "ooh58Lbl9IEROJ-KYJqimQLI0vxWpVuP9t91QsVX8JrfYZ7RuPK56g=="), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = as.raw(c(0x7b, 0x0a, 0x20, 0x20, 0x22, 0x74, 0x79, 
    0x70, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x61, 0x62, 0x6f, 
    0x75, 0x74, 0x3a, 0x62, 0x6c, 0x61, 0x6e, 0x6b, 0x22, 0x2c, 
    0x0a, 0x20, 0x20, 0x22, 0x74, 0x69, 0x74, 0x6c, 0x65, 0x22, 
    0x20, 0x3a, 0x20, 0x22, 0x42, 0x61, 0x64, 0x20, 0x52, 0x65, 
    0x71, 0x75, 0x65, 0x73, 0x74, 0x22, 0x2c, 0x0a, 0x20, 0x20, 
    0x22, 0x73, 0x74, 0x61, 0x74, 0x75, 0x73, 0x22, 0x20, 0x3a, 
    0x20, 0x34, 0x30, 0x30, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x64, 
    0x65, 0x74, 0x61, 0x69, 0x6c, 0x22, 0x20, 0x3a, 0x20, 0x22, 
    0x53, 0x65, 0x61, 0x72, 0x63, 0x68, 0x65, 0x64, 0x20, 0x62, 
    0x79, 0x20, 0x53, 0x79, 0x6e, 0x6f, 0x6e, 0x79, 0x6d, 0x3a, 
    0x20, 0x46, 0x6f, 0x75, 0x6e, 0x64, 0x20, 0x30, 0x20, 0x72, 
    0x65, 0x73, 0x75, 0x6c, 0x74, 0x73, 0x20, 0x66, 0x6f, 0x72, 
    0x20, 0x27, 0x67, 0x76, 0x66, 0x64, 0x73, 0x27, 0x2e, 0x22, 
    0x2c, 0x0a, 0x20, 0x20, 0x22, 0x69, 0x6e, 0x73, 0x74, 0x61, 
    0x6e, 0x63, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x2f, 0x63, 
    0x68, 0x65, 0x6d, 0x69, 0x63, 0x61, 0x6c, 0x2f, 0x73, 0x65, 
    0x61, 0x72, 0x63, 0x68, 0x2f, 0x65, 0x71, 0x75, 0x61, 0x6c, 
    0x2f, 0x67, 0x76, 0x66, 0x64, 0x73, 0x22, 0x2c, 0x0a, 0x20, 
    0x20, 0x22, 0x73, 0x75, 0x67, 0x67, 0x65, 0x73, 0x74, 0x69, 
    0x6f, 0x6e, 0x73, 0x22, 0x20, 0x3a, 0x20, 0x5b, 0x20, 0x22, 
    0x61, 0x70, 0x66, 0x64, 0x73, 0x22, 0x2c, 0x20, 0x22, 0x75, 
    0x70, 0x66, 0x64, 0x73, 0x22, 0x2c, 0x20, 0x22, 0x70, 0x66, 
    0x64, 0x73, 0x22, 0x2c, 0x20, 0x22, 0x76, 0x66, 0x64, 0x66, 
    0x22, 0x20, 0x5d, 0x0a, 0x7d)), date = structure(1731080818, class = c("POSIXct", 
    "POSIXt"), tzone = "GMT"), times = c(redirect = 0, namelookup = 7.9e-05, 
    connect = 0, pretransfer = 0.000187, starttransfer = 0.239085, 
    total = 0.239134)), class = "response")
